pub enum NpmError {
Build(Error),
Install(Error),
SearchIndex(Error),
Tailwind(Error),
}Expand description
Errors that can occur while running npm commands.
Variants
Build(Error)
Failed to run npm run build in the theme directory.
Install(Error)
Failed to run npm install in the theme directory.
SearchIndex(Error)
Failed to run npx pagefind in the output directory.
Tailwind(Error)
Failed to run npx @tailwindcss/cli.